using UnityEngine;
using UnityEngine.EventSystems;

public class AppIcon : MonoBehaviour, IPointerEnterHandler, IPointerExitHandler, IPointerClickHandler
{
    [SerializeField] private Transform background;
    [SerializeField] private Transform icon;
    [SerializeField] private WindowController appWindow;

    private bool _hovering;
    private Vector3 _backgroundOriginalPosition;
    private Vector3 _iconOriginalPosition;
    private Vector3 _hoveredBackgroundPosition;
    private Vector3 _hoveredIconPosition;

    private void Start()
    {
        _backgroundOriginalPosition = background.localPosition;
        _iconOriginalPosition = icon.localPosition;
        _hoveredBackgroundPosition = _backgroundOriginalPosition + new Vector3(0, 0, -100f);
        _hoveredIconPosition = _backgroundOriginalPosition + new Vector3(0, 0, -200f);
    }

    private void Update()
    {
        if (_hovering)
        {
            Pop();
        }
        else
        {
            Reset();
        }
    }

    public void OnPointerEnter(PointerEventData eventData)
    {
        _hovering = true;
    }

    public void OnPointerExit(PointerEventData eventData)
    {
        _hovering = false;
    }
    
    public void OnPointerClick(PointerEventData eventData)
    {
        if (appWindow == null) return;
        MainController.Instance.OpenApp(appWindow.canvasGroup);
    }

    private void Pop()
    {
        var newBackgroundPosition = Vector3.Lerp(background.localPosition, _hoveredBackgroundPosition, Time.deltaTime * 50f);
        var newIconPosition = Vector3.Lerp(icon.localPosition, _hoveredIconPosition, Time.deltaTime * 50f);
        background.localPosition = newBackgroundPosition;
        icon.localPosition = newIconPosition;
    }

    private void Reset()
    {
        var newBackgroundPosition = Vector3.Lerp(background.localPosition, _backgroundOriginalPosition, Time.deltaTime * 50f);
        var newIconPosition = Vector3.Lerp(icon.localPosition, _iconOriginalPosition, Time.deltaTime * 50f);
        background.localPosition = newBackgroundPosition;
        icon.localPosition = newIconPosition;
    }
}
