using System;
using System.Collections;
using UnityEngine;

public class MainController : MonoBehaviour
{
    [SerializeField] CanvasGroup menuGroup;

    private static MainController _instance;
    
    private bool _fading;
    private CanvasGroup _currentFadeOut;
    private CanvasGroup _currentFadeIn;
    
    public static MainController Instance => _instance;

    private void Awake()
    {
        if (_instance == null) _instance = this;
    }

    private void FadeOutGroup(CanvasGroup group, Action callback)
    {
        IEnumerator StartFadeOut()
        {
            while (group.alpha > 0)
            {
                group.alpha -= Time.deltaTime * 3;
                yield return null;
            }
            group.gameObject.SetActive(false);
            callback?.Invoke();
        }
        
        StartCoroutine(StartFadeOut());
    }
    
    private void FadeInGroup(CanvasGroup group)
    {
        IEnumerator StartFadeIn()
        {
            while (group.alpha < 1)
            {
                group.alpha += Time.deltaTime * 3;
                yield return null;
            }
        }
        
        group.alpha = 0;
        group.gameObject.SetActive(true);
        StartCoroutine(StartFadeIn());
    }

    public void OpenApp(CanvasGroup appWindow)
    {
        FadeOutGroup(menuGroup, () => FadeInGroup(appWindow));
    }
    
    public void BackToMenu(CanvasGroup appWindow)
    {
        FadeOutGroup(appWindow, () => FadeInGroup(menuGroup));
    }
}
